@@ -59,7 +59,7 @@ static QFont nearestExistingFont(const QFont &font)
 {
     QFontDatabase dbase;
 
-    // Initialize font data accoring to given font object.
+    // Initialize font data according to given font object.
     QString family = font.family();
     QString style = dbase.styleString(font);
     qreal size = font.pointSizeF();
@@ -273,7 +273,7 @@ bool FontAASettings::save(KXftConfig::AntiAliasing::State aaState)
     // TODO: With AASystem the changes already made by this module should be reverted somehow.
 #if defined(HAVE_FONTCONFIG) && defined (HAVE_X11)
     if (mod || (m_antiAliasing != m_antiAliasingOriginal) || m_dpi != m_dpiOriginal) {
-        KMessageBox::information(0,
+        KMessageBox::information(nullptr,
                                  i18n(
                                      "<p>Some changes such as anti-aliasing or DPI will only affect newly started applications.</p>"
                                  ), i18n("Font Settings Changed"), "FontSettingsChanged");
@@ -307,7 +307,7 @@ void FontAASettings::defaults()
     setExcludeFrom(8);
     setAntiAliasing(1);
     m_antiAliasingOriginal = m_antiAliasing;
-    setDpi(96);
+    setDpi(0);
     setSubPixelCurrentIndex(KXftConfig::SubPixel::NotSet);
     setHintingCurrentIndex(KXftConfig::Hint::NotSet);
 }
@@ -442,7 +442,7 @@ KFonts::KFonts(QObject *parent, const QVariantList &args)
     about->addAuthor(i18n("Antonis Tsiapaliokas"), QString(), "antonis.tsiapaliokas@kde.org");
     setAboutData(about);
     qmlRegisterType<QStandardItemModel>();
-    setButtons(Apply | Default);
+    setButtons(Apply | Default | Help);
 
     auto updateState = [this]() {
         setNeedsSave(m_fontAASettings->needsSave());
@@ -669,7 +669,7 @@ QFont KFonts::windowTitleFont() const
 void KFonts::adjustAllFonts()
 {
     QFont font = m_generalFont;
-    KFontChooser::FontDiffFlags fontDiffFlags = 0;
+    KFontChooser::FontDiffFlags fontDiffFlags;
     int ret = KFontDialog::getFontDiff(font, fontDiffFlags, KFontChooser::NoDisplayFlags);
 
     if (ret == KDialog::Accepted && fontDiffFlags) {
