@@ -138,11 +138,11 @@ CJobRunner::CJobRunner(QWidget *parent, int xid)
              itsAutoSkip(false),
              itsCancelClicked(false),
              itsModified(false),
-             itsTempDir(0L)
+             itsTempDir(nullptr)
 {
     setModal(true);
 
-    if(NULL==parent && 0!=xid)
+    if(nullptr==parent && 0!=xid)
         XSetTransientForHint(QX11Info::display(), winId(), xid);
 
     itsButtonBox = new QDialogButtonBox;
@@ -204,7 +204,7 @@ CJobRunner::CJobRunner(QWidget *parent, int xid)
     itsStack->insertWidget(PAGE_CANCEL, page);
 
     if(KSharedConfig::openConfig(KFI_UI_CFG_FILE)->group(CFG_GROUP).readEntry(CFG_DONT_SHOW_FINISHED_MSG, false))
-        itsDontShowFinishedMsg=0L;
+        itsDontShowFinishedMsg= nullptr;
     else
     {
         page=new QFrame(itsStack);
@@ -256,8 +256,8 @@ void CJobRunner::getAssociatedUrls(const QUrl &url, QList<QUrl> &list, bool afmA
 
     if(check)
     {
-        const char *afm[]={"afm", "AFM", "Afm", NULL},
-                   *pfm[]={"pfm", "PFM", "Pfm", NULL};
+        const char *afm[]={"afm", "AFM", "Afm", nullptr},
+                   *pfm[]={"pfm", "PFM", "Pfm", nullptr};
         bool       gotAfm(false),
                    localFile(url.isLocalFile());
         int        e;
@@ -383,7 +383,7 @@ int CJobRunner::exec(ECommand cmd, const ItemList &urls, bool destIsSystem)
     if(itsTempDir)
     {
         delete itsTempDir;
-        itsTempDir=0L;
+        itsTempDir= nullptr;
     }
     return rv;
 }
