@@ -109,7 +109,7 @@ extern "C"
 class StylePreview : public QWidget, public Ui::StylePreview
 {
 public:
-    StylePreview(QWidget *parent = 0)
+    StylePreview(QWidget *parent = nullptr)
     : QWidget(parent)
     {
         setupUi(this);
@@ -156,7 +156,7 @@ QString KCMStyle::defaultStyle()
 }
 
 KCMStyle::KCMStyle( QWidget* parent, const QVariantList& )
-    : KCModule( parent ), appliedStyle(NULL)
+    : KCModule( parent ), appliedStyle(nullptr)
 {
     setQuickHelp( i18n("<h1>Style</h1>"
             "This module allows you to modify the visual appearance "
@@ -176,7 +176,6 @@ KCMStyle::KCMStyle( QWidget* parent, const QVariantList& )
 
     about->addAuthor(i18n("Karol Szwed"), QString(), QStringLiteral("gallium@kde.org"));
     about->addAuthor(i18n("Daniel Molkentin"), QString(), QStringLiteral("molkentin@kde.org"));
-    about->addAuthor(i18n("Ralf Nolden"), QString(), QStringLiteral("nolden@kde.org"));
     setAboutData( about );
 
     // Setup pages and mainLayout
@@ -535,7 +534,7 @@ void KCMStyle::loadStyle( KConfig& config )
     {
         QString id = (*it).toLower();
         // Find the entry.
-        if ( (entry = styleEntries[id]) != 0 )
+        if ( (entry = styleEntries[id]) != nullptr )
         {
             // Do not add hidden entries
             if (entry->hidden)
